# Django NER Trainer

Tools for training spaCy Named Entity Recognition models in Django


## Documentation

Documentation is available in the [docs directory](./docs/index.md) and at https://johnfraney.github.io/django-ner-trainer.


## Credits

Tools used in rendering this package:

[Cookiecutter](https://github.com/audreyr/cookiecutter)

[`cookiecutter-djangopackage`](https://github.com/pydanny/cookiecutter-djangopackage)


## Code of Conduct

Everyone interacting in the project's codebases, issue trackers, chat rooms, and mailing lists is expected to follow the [PyPA Code of Conduct](https://www.pypa.io/en/latest/code-of-conduct/).
